@@ -6,8 +6,8 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-my ($message, $setting, $aubbc, $Current_version, %msg) =
- ('[br][utf://#x23]', '', '', '', (1 => 'Test good ', 2 => 'Test error ',) );
+my ($count, $message, $setting, $aubbc, $Current_version, %msg) =
+ (1, '[br][utf://#x23]', '', '', '', (1 => 'Test good ', 2 => 'Test error ',) );
 
 BEGIN {
  $| = 1;
@@ -20,31 +20,34 @@ $aubbc = new AUBBC;
  # did it load?
  #$aubbc = ''; # main reinforce failure
  $aubbc
-  ? print $msg{1} . "1\n"
-  : print $msg{2} . "1\n";
+  ? print $msg{1} . "$count\n"
+  : print $msg{2} . "$count\n";
 
  $aubbc->settings(html_type => 'xhtml') if $aubbc;
  $message = $aubbc->do_all_ubbc($message) if $aubbc;
  $setting = $aubbc->get_setting('html_type') if $aubbc;
  $Current_version = $aubbc->version() if $aubbc;
 
+ $count++;
  # did it convert?
  #$message .= ']'; # reinforce failure
  $message !~ m/[\[\]\:]+/
-  ? print $msg{1} . "2\n"
-  : print $msg{2} . "2\n";
+  ? print $msg{1} . "$count\n"
+  : print $msg{2} . "$count\n";
 }
 
 END {
+ $count++;
  # did we get a setting?
  #$setting = 5; # reinforce failure
  $setting eq ' /'
-  ? print $msg{1} . "3\n"
-  : print $msg{2} . "3\n";
+  ? print $msg{1} . "$count\n"
+  : print $msg{2} . "$count\n";
 
+  $count++;
  # did we get the version?
  #$Current_version = 5; # reinforce failure
- $Current_version eq '4.01'
-  ? print $msg{1} . "4\n"
-  : print $msg{2} . "4\n";
+ $Current_version eq '4.02'
+  ? print $msg{1} . "$count\n"
+  : print $msg{2} . "$count\n";
 }
